@@ -171,6 +171,11 @@ static void registerVariables(KateVariableExpansionManager &mng)
         },
         true));
 
+    mng.addVariable(Variable(
+        QStringLiteral("PercentEncoded:"), i18n("Encode text to make it URL compatible."), [](const QStringView &str, KTextEditor::View *) {
+            return QString::fromUtf8(QUrl::toPercentEncoding(str.mid(15).toString()));
+        }, true));
+
     mng.addVariable(Variable(
         QStringLiteral("UUID"), i18n("Generate a new UUID."), [](const QStringView &, KTextEditor::View *) { return QUuid::createUuid().toString(QUuid::WithoutBraces); }, false));
 }
